#[non_exhaustive]#[repr(C)]pub enum CalendarKind {
Show 18 variants
Iso = 0,
Gregorian = 1,
Buddhist = 2,
Japanese = 3,
JapaneseExtended = 4,
Ethiopian = 5,
EthiopianAmeteAlem = 6,
Indian = 7,
Coptic = 8,
Dangi = 9,
Chinese = 10,
Hebrew = 11,
HijriTabularTypeIIFriday = 12,
HijriSimulatedMecca = 18,
HijriTabularTypeIIThursday = 14,
HijriUmmAlQura = 15,
Persian = 16,
Roc = 17,
}Expand description
The various calendar types currently supported by Calendar
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Iso = 0
The kind of an Iso calendar
Gregorian = 1
The kind of a Gregorian calendar
Buddhist = 2
The kind of a Buddhist calendar
Japanese = 3
The kind of a Japanese calendar with modern eras
JapaneseExtended = 4
The kind of a Japanese calendar with modern and historic eras
Ethiopian = 5
The kind of an Ethiopian calendar, with Amete Mihret era
EthiopianAmeteAlem = 6
The kind of an Ethiopian calendar, with Amete Alem era
Indian = 7
The kind of a Indian calendar
Coptic = 8
The kind of a Coptic calendar
Dangi = 9
The kind of a Dangi calendar
Chinese = 10
The kind of a Chinese calendar
Hebrew = 11
The kind of a Hebrew calendar
HijriTabularTypeIIFriday = 12
The kind of a Hijri tabular, type II leap years, Friday epoch, calendar
HijriSimulatedMecca = 18
The kind of a Hijri simulated, Mecca calendar
HijriTabularTypeIIThursday = 14
The kind of a Hijri tabular, type II leap years, Thursday epoch, calendar
HijriUmmAlQura = 15
The kind of a Hijri Umm al-Qura calendar
Persian = 16
The kind of a Persian calendar
Roc = 17
The kind of a Roc calendar
Implementations
Sourceimpl CalendarKind
impl CalendarKind
Sourcepub fn create(locale: &Locale) -> Self
pub fn create(locale: &Locale) -> Self
Creates a new CalendarKind for the specified locale, using compiled data.